@@ -72,6 +72,7 @@
 #define SUMMARY_SEARCH_BODY_HISTORY	"summary_searchbody_history"
 #define SUMMARY_SEARCH_ADV_CONDITION_HISTORY	"summarysearch_adv_history"
 #define MESSAGE_SEARCH_HISTORY	"messagesearch_history"
+#define COMPOSE_SAVE_TO_HISTORY	"compose_save_to_history"
 #define ADDRESSBOOK_CUSTOM_ATTRIBUTES "attributesrc"
 #define TEMPLATE_DIR		"templates"
 #define TMP_DIR			"tmp"
@@ -91,7 +92,6 @@
 #define USERS_ML_ADDR		"claws-mail-users@dotsrc.org"
 #define GPL_URI			"http://www.gnu.org/licenses/gpl.html"
 #define DONATE_URI		"http://www.claws-mail.org/sponsors.php"
-#define OPENSSL_URI		"http://www.openssl.org/"
 #define RELEASE_NOTES_FILE	"RELEASE_NOTES"
 #define THEMEINFO_FILE		".claws_themeinfo"
 #define FOLDER_LIST		"folderlist.xml"
