@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * 
  */
 
 #ifndef __TEMPLATE_H__
@@ -29,6 +29,7 @@ struct _Template {
 	gchar *load_filename;
 	gchar *name;
 	gchar *subject;
+	gchar *from;
 	gchar *to;
 	gchar *cc;
 	gchar *bcc;		
@@ -36,10 +37,8 @@ struct _Template {
 };
 
 void template_free		(Template	*tmpl);
-void template_clear_config	(GSList		*tmpl_list);
 
 GSList *template_read_config	(void);
-void template_write_config	(GSList		*tmpl_list);
 
 GSList *template_get_config	(void);
 void template_set_config	(GSList		*tmpl_list);
