@@ -7,7 +7,7 @@ static char *TEAM_LIST[] = {
 "Ricardo Mones Lastra <ricardo@mones.org>",
 "Colin Leroy <colin@colino.net>",
 "Paul Mangan <paul@claws-mail.org>",
-"Martin Schaaf <mascha1@users.sf.net>",
+"Salvatore De Paolis <iwkse@claws-mail.org>", 
 "Fabien Vantard <fzzzzz@gmail.com>",
 NULL
 };
@@ -22,6 +22,7 @@ static char *EX_TEAM_LIST[] = {
 "Thorsten Maerz",
 "Leandro A. F. Pereira",
 "Luke Plant",
+"Martin Schaaf",
 "Carsten Schurig",
 "Sergey Vlasov",
 "Hiroyuki Yamamoto",
@@ -31,31 +32,21 @@ NULL
 static char *TRANS_TEAM_LIST[] = {
 "[bg] Yasen Pramatarov <yasen@lindeas.com>",
 "[ca] Miquel Oliete <ktalanet@yahoo.es>",
-"[cs] Tim <timbrain@post.cz>",
-"[cs] Petr Vanek <vanous@penguin.cz>",
 "[de] Stephan Sachse <white@dev-zero.com>",
 "[en_GB] Paul Mangan <paul@claws-mail.org>",
-"[el] Stavros Giannouris <stavrosg2002@freemail.gr>",
 "[es] Ricardo Mones Lastra <ricardo@mones.org>",
 "[fi] Flammie Pirinen <flammie@iki.fi>",
-"[fr] Fabien Vantard <fzzzzz@gmail.com>",
-"[he] Ofer <oc666@netvision.net.il>",
-"[hr] Dragan <drleskov@inet.hr>",
+"[fr] Tristan Chabredier <wwp@claws-mail.org>",
 "[hu] Pader Rezso <rezso@rezso.net>",
 "[it] Andrea Spadaccini <a.spadaccini@catania.linux.it>",
-"[ja] Rui Hirokawa <rui_hirokawa@ybb.ne.jp>",
-"[ko] SungHyun Nam <namsh@kldp.org>",
-"[nb] Geir Helland <pjallabais@users.sf.net>",
-"[nl] Tim Dijkstra <tim@famdijkstra.org>",
-"[pl] Emilian Nowak <eminowbl@posejdon.wpk.p.lodz.pl>",
-"[pl] Quar <Quar@sylpheed.quar.org>",
+"[nl] Marcel Pol <mpol@gmx.net>",
+"[pl] Emilian Nowak <emil5@go2.pl>",
 "[pt_BR] Frederico Goncalves Guimaraes <fggdebian@yahoo.com.br>",
-"[ru] Pavlo Bohmat <bohm@ukr.net>",
+"[ru] Aleksei Miheev <aleksei@miheev.info>",
 "[sk] Andrej Kacian <andrej@kacian.sk>",
 "[sr] Aleksandar Urosevic <urke@users.sf.net>",
-"[sv] Anders Trobck <sylpheed@troback.com>",
+"[sv] Lars Persson Fink <lars.p.fink@gmail.com>",
 "[zh_CN] Ralgh Young <bamanzi@gmail.com>",
-"[zh_TW] Wei-Lun Chao <chaoweilun@pcmail.com.tw>",
 NULL
 };
 
@@ -101,6 +92,7 @@ static char *CONTRIBS_LIST[] = {
 "Tsu-Fan Cheng",
 "Manrat Chobchuen",
 "Rich Coe",
+"Jonathan Corbet",
 "Christian Cornelssen",
 "George Danchev",
 "Matthieu Dazy",
